@@ -6,7 +6,7 @@ import aiohttp.web
 class GoodResponse(aiohttp.web.Response):
     def __init__(self, result, status_code=200, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.body = json.dumps({"result": result})
+        self.body = json.dumps({"result": result, "error": False})
         self._status = status_code
         self.content_type = "application/json"
 
@@ -14,6 +14,6 @@ class GoodResponse(aiohttp.web.Response):
 class BadResponse(aiohttp.web.Response):
     def __init__(self, result, status_code=400, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.body = json.dumps({"error": result})
+        self.body = json.dumps({"error": True, "reason": result})
         self._status = status_code
         self.content_type = "application/json"
